@@ -32,12 +32,6 @@ from abc import ABC, abstractmethod
 
 log = logging.getLogger("argopy.stores")
 
-try:
-    from tqdm import tqdm
-except ModuleNotFoundError:
-    log.debug("tqdm not found, argopy needs tqdm installed to display progress bars")
-    tqdm = lambda fct, lst: fct  # noqa: E731
-
 
 def new_fs(protocol: str = '', cache: bool = False, cachedir: str = OPTIONS['cachedir'], **kwargs):
     """ Create a new fsspec file system
@@ -85,7 +79,8 @@ class argo_store_proto(ABC):
 
         Should this class inherits from fsspec.spec.AbstractFileSystem ?
     """
-    protocol = ''  # File system name, one in fsspec.registry.known_implementations
+    protocol = ''
+    """str: File system name, one in fsspec.registry.known_implementations"""
 
     def __init__(self,
                  cache: bool = False,
@@ -211,10 +206,11 @@ class filestore(argo_store_proto):
         with self.open(url) as of:
             log.debug("Opening dataset: %s" % url)
             ds = xr.open_dataset(of, *args, **kwargs)
+            ds.load()
         if "source" not in ds.encoding:
             if isinstance(url, str):
                 ds.encoding["source"] = url
-        return ds.load().copy()
+        return ds.copy()
 
     def _mfprocessor(self, url, preprocess=None, *args, **kwargs):
         # Load data
@@ -483,7 +479,7 @@ class httpstore(argo_store_proto):
                     data = None
                     try:
                         data = future.result()
-                    except Exception as e:
+                    except Exception:
                         failed.append(future_to_url[future])
                         if errors == 'ignore':
                             log.debug("Ignored error with this url: %s" % strUrl(future_to_url[future]))
@@ -509,7 +505,7 @@ class httpstore(argo_store_proto):
                 data = None
                 try:
                     data = self._mfprocessor_dataset(url, preprocess=preprocess, *args, **kwargs)
-                except Exception as e:
+                except Exception:
                     failed.append(url)
                     if errors == 'ignore':
                         log.debug("Ignored error with this url: %s" % strUrl(url))  # See fsspec.http logger for more
@@ -553,7 +549,7 @@ class httpstore(argo_store_proto):
             :class:`pandas.DataFrame`
 
         """
-        log.debug("Reading csv: %s" % url)
+        log.debug("Opening/reading csv: %s" % url)
         with self.open(url) as of:
             df = pd.read_csv(of, **kwargs)
         return df
@@ -571,12 +567,18 @@ class httpstore(argo_store_proto):
 
         """
         log.debug("Opening json: %s" % url)
-        try:
-            with self.open(url) as of:
-                js = json.load(of, **kwargs)
-            return js
-        except json.JSONDecodeError:
-            raise
+        # try:
+        #     with self.open(url) as of:
+        #         js = json.load(of, **kwargs)
+        #     return js
+        # except ClientResponseError:
+        #     raise
+        # except json.JSONDecodeError:
+        #     raise
+        data = self.fs.cat_file(url)
+        js = json.loads(data, **kwargs)
+        self.register(url)
+        return js
 
     def _mfprocessor_json(self, url, preprocess=None, *args, **kwargs):
         # Load data
@@ -646,7 +648,7 @@ class httpstore(argo_store_proto):
                     data = None
                     try:
                         data = future.result()
-                    except Exception as e:
+                    except Exception:
                         failed.append(future_to_url[future])
                         if errors == 'ignore':
                             log.debug("Ignored error with this url: %s" % strUrl(future_to_url[future]))
@@ -672,7 +674,7 @@ class httpstore(argo_store_proto):
                 data = None
                 try:
                     data = self._mfprocessor_json(url, preprocess=preprocess, *args, **kwargs)
-                except Exception as e:
+                except Exception:
                     failed.append(url)
                     if errors == 'ignore':
                         log.debug("Ignored error with this url: %s" % strUrl(url))
