@@ -21,11 +21,16 @@ from argopy.utilities import (
     is_box,
     is_list_of_strings,
     format_oneline, is_indexbox,
-    check_wmo, is_wmo
+    check_wmo, is_wmo,
+    wmo2box,
+    modified_environ,
+    wrap_longitude,
+    toYearFraction, YearFraction_to_datetime,
+    TopoFetcher
 )
 from argopy.errors import InvalidFetcherAccessPoint, FtpPathError
 from argopy import DataFetcher as ArgoDataFetcher
-from . import requires_connection, requires_localftp
+from . import requires_connection, requires_localftp, safe_to_server_errors
 
 
 def test_invalid_dictionnary():
@@ -483,3 +488,67 @@ def test_check_wmo():
     assert check_wmo([1234567]) == [1234567]
     assert check_wmo([12345, 1234567]) == [12345, 1234567]
     assert check_wmo(np.array((12345, 1234567), dtype='int')) == [12345, 1234567]
+
+
+def test_modified_environ():
+    os.environ["DUMMY_ENV_ARGOPY"] = 'initial'
+    with modified_environ(DUMMY_ENV_ARGOPY='toto'):
+        assert os.environ['DUMMY_ENV_ARGOPY'] == 'toto'
+    assert os.environ['DUMMY_ENV_ARGOPY'] == 'initial'
+    os.environ.pop('DUMMY_ENV_ARGOPY')
+
+
+def test_wmo2box():
+    with pytest.raises(ValueError):
+        wmo2box(12)
+    with pytest.raises(ValueError):
+        wmo2box(8000)
+    with pytest.raises(ValueError):
+        wmo2box(2000)
+
+    def complete_box(b):
+        b2 = b.copy()
+        b2.insert(4, 0.)
+        b2.insert(5, 10000.)
+        return b2
+
+    assert is_box(complete_box(wmo2box(1212)))
+    assert is_box(complete_box(wmo2box(3324)))
+    assert is_box(complete_box(wmo2box(5402)))
+    assert is_box(complete_box(wmo2box(7501)))
+
+
+def test_wrap_longitude():
+    assert wrap_longitude(np.array([-20])) == 340
+    assert wrap_longitude(np.array([40])) == 40
+    assert np.all(np.equal(wrap_longitude(np.array([340, 20])), np.array([340, 380])))
+
+
+def test_toYearFraction():
+    assert toYearFraction(pd.to_datetime('202001010000')) == 2020
+    assert toYearFraction(pd.to_datetime('202001010000', utc=True)) == 2020
+    assert toYearFraction(pd.to_datetime('202001010000')+pd.offsets.DateOffset(years=1)) == 2021
+
+
+def test_YearFraction_to_datetime():
+    assert YearFraction_to_datetime(2020) == pd.to_datetime('202001010000')
+    assert YearFraction_to_datetime(2020+1) == pd.to_datetime('202101010000')
+
+
+class Test_TopoFetcher():
+
+    @safe_to_server_errors
+    def test_fetching(self):
+        box = [81, 123, -67, -54]
+        fetcher = TopoFetcher(box, ds='gebco', stride=[10, 10], cache=True)
+        ds = fetcher.to_xarray()
+        assert isinstance(ds, xr.Dataset)
+        assert 'elevation' in ds.data_vars
+
+    @safe_to_server_errors
+    def test_fetching_cached(self):
+        box = [81, 123, -67, -54]
+        fetcher = TopoFetcher(box, ds='gebco', stride=[10, 10], cache=False)
+        ds = fetcher.to_xarray()
+        assert isinstance(ds, xr.Dataset)
+        assert 'elevation' in ds.data_vars
