@@ -12,6 +12,7 @@ import warnings
 import urllib
 import json
 import collections
+import copy
 from functools import reduce
 from packaging import version
 
@@ -41,6 +42,7 @@ from argopy.errors import (
     FtpPathError,
     InvalidFetcher,
     InvalidFetcherAccessPoint,
+    InvalidOption
 )
 
 try:
@@ -96,11 +98,11 @@ def mapp_dict(Adictionnary, Avalue):
 
 def list_available_data_src():
     """ List all available data sources """
-    AVAILABLE_SOURCES = {}
+    sources = {}
     try:
         from .data_fetchers import erddap_data as Erddap_Fetchers
 
-        AVAILABLE_SOURCES["erddap"] = Erddap_Fetchers
+        sources["erddap"] = Erddap_Fetchers
     except Exception:
         warnings.warn(
             "An error occurred while loading the ERDDAP data fetcher, "
@@ -112,7 +114,7 @@ def list_available_data_src():
     try:
         from .data_fetchers import localftp_data as LocalFTP_Fetchers
 
-        AVAILABLE_SOURCES["localftp"] = LocalFTP_Fetchers
+        sources["localftp"] = LocalFTP_Fetchers
     except Exception:
         warnings.warn(
             "An error occurred while loading the local FTP data fetcher, "
@@ -124,7 +126,7 @@ def list_available_data_src():
     try:
         from .data_fetchers import argovis_data as ArgoVis_Fetchers
 
-        AVAILABLE_SOURCES["argovis"] = ArgoVis_Fetchers
+        sources["argovis"] = ArgoVis_Fetchers
     except Exception:
         warnings.warn(
             "An error occurred while loading the ArgoVis data fetcher, "
@@ -133,7 +135,8 @@ def list_available_data_src():
         )
         pass
 
-    return AVAILABLE_SOURCES
+    # return dict(sorted(sources.items()))
+    return sources
 
 
 def list_available_index_src():
@@ -167,7 +170,7 @@ def list_available_index_src():
 
 
 def list_standard_variables():
-    """ Return the list of variables for standard users """
+    """ List of variables for standard users """
     return [
         "DATA_MODE",
         "LATITUDE",
@@ -200,7 +203,7 @@ def list_standard_variables():
 
 
 def list_multiprofile_file_variables():
-    """ Return the list of variables in a netcdf multiprofile file.
+    """ List of variables in a netcdf multiprofile file.
 
         This is for files created by GDAC under <DAC>/<WMO>/<WMO>_prof.nc
     """
@@ -471,6 +474,9 @@ def show_versions(file=sys.stdout):  # noqa: C901
         ("setuptools", lambda mod: mod.__version__),
         ("sphinx", lambda mod: mod.__version__),
         ("zarr", lambda mod: mod.__version__),
+        ("tqdm", lambda mod: mod.__version__),
+        ("ipykernel", lambda mod: mod.__version__),
+        ("ipywidgets", lambda mod: mod.__version__),
     ]
 
     deps_blob = list()
@@ -510,8 +516,9 @@ def show_options(file=sys.stdout):  # noqa: C901
     """
     print("\nARGOPY OPTIONS", file=file)
     print("--------------", file=file)
-
-    for k, v in OPTIONS.items():
+    opts = copy.deepcopy(OPTIONS)
+    opts = dict(sorted(opts.items()))
+    for k, v in opts.items():
         print(f"{k}: {v}", file=file)
 
 
@@ -554,31 +561,24 @@ def isAPIconnected(src="erddap", data=True):
         bool
     """
     if data:
-        AVAILABLE_SOURCES = list_available_data_src()
+        list_src = list_available_data_src()
     else:
-        AVAILABLE_SOURCES = list_available_index_src()
-    if src in AVAILABLE_SOURCES and getattr(
-        AVAILABLE_SOURCES[src], "api_server_check", None
+        list_src = list_available_index_src()
+
+    if src in list_src and getattr(
+        list_src[src], "api_server_check", None
     ):
         if "localftp" in src:
-            # This is a special case because the source here is a local folder, and the folder validity is checked
-            # when setting the option value of 'local_ftp'
-            # So here, we just need to catch the appropriate error after a call to set_option
-            # opts = {"src": src, "local_ftp": OPTIONS["local_ftp"]}
-            # try:
-            #     set_options(**opts)
-            #     return True
-            # except OptionValueError:
-            #     return False
-            return check_localftp(OPTIONS["local_ftp"])
+            # This is a special case because the source here is a local folder
+            result = check_localftp(OPTIONS["local_ftp"])
         else:
-            with set_options(src=src):
-                return isconnected(AVAILABLE_SOURCES[src].api_server_check)
+            result = isconnected(list_src[src].api_server_check)
+        return result
     else:
         raise InvalidFetcher
 
 
-def erddap_ds_exists(ds: str = "ArgoFloats", erddap: str = 'http://www.ifremer.fr/erddap') -> bool:
+def erddap_ds_exists(ds: str = "ArgoFloats", erddap: str = 'https://www.ifremer.fr/erddap') -> bool:
     """ Check if a dataset exists on a remote erddap server
     return a bool
 
@@ -587,7 +587,7 @@ def erddap_ds_exists(ds: str = "ArgoFloats", erddap: str = 'http://www.ifremer.f
     ds: str
         Name of the erddap dataset to check (default: 'ArgoFloats')
     erddap: str
-        Url of the erddap server (default: 'http://www.ifremer.fr/erddap')
+        Url of the erddap server (default: 'https://www.ifremer.fr/erddap')
 
     Return
     ------
@@ -632,15 +632,31 @@ def badge(label="label", message="message", color="green", insert=False):
         return Image(url=img)
 
 
-def fetch_status(stdout="html", insert=True):
-    """ Fetch and report web API status """
+def fetch_status(stdout: str = "html", insert: bool = True):
+    """ Fetch and report web API status
+
+    Parameters
+    ----------
+    stdout: str
+        Format of the results, default is 'html'. Otherwise a simple string.
+    insert: bool
+        Print or display results directly in stdout format.
+
+    Returns
+    -------
+    IPython.display.HTML or str
+    """
     results = {}
-    for api, mod in list_available_data_src().items():
+    list_src = list_available_data_src()
+    for api, mod in list_src.items():
         if getattr(mod, "api_server_check", None):
             # status = isconnected(mod.api_server_check)
             status = isAPIconnected(api)
-            # message = "up" if status else "down"
-            message = "ok" if status else "offline"
+            if api=='localftp' and OPTIONS['local_ftp'] == '-':
+                message = "ok" if status else "path undefined !"
+            else:
+                # message = "up" if status else "down"
+                message = "ok" if status else "offline"
             results[api] = {"value": status, "message": message}
 
     if "IPython" in sys.modules and stdout == "html":
@@ -839,15 +855,19 @@ class Chunker:
         ----------
         request: dict
             Access point request to be chunked. One of the following:
-            {'box': [lon_min, lon_max, lat_min, lat_max, dpt_min, dpt_max, time_min, time_max]}
-            {'box': [lon_min, lon_max, lat_min, lat_max, dpt_min, dpt_max]}
-            {'wmo': [wmo1, wmo2, ...], 'cyc': [0,1, ...]}
+
+            - {'box': [lon_min, lon_max, lat_min, lat_max, dpt_min, dpt_max, time_min, time_max]}
+            - {'box': [lon_min, lon_max, lat_min, lat_max, dpt_min, dpt_max]}
+            - {'wmo': [wmo1, wmo2, ...], 'cyc': [0,1, ...]}
         chunks: 'auto' or dict
             Dictionary with request access point as keys and number of chunks to create as values.
+
             Eg: {'wmo':10} will create a maximum of 10 chunks along WMOs.
         chunksize: dict, optional
             Dictionary with request access point as keys and chunk size as values (used as maximum values in
-            'auto' chunking). Eg: {'wmo': 5} will create chunks with as many as 5 WMOs each.
+            'auto' chunking).
+
+            Eg: {'wmo': 5} will create chunks with as many as 5 WMOs each.
 
         """
         self.request = request
@@ -1170,22 +1190,22 @@ def is_box(box: list, errors="raise"):
 
     # Types:
     tests["lon_min must be numeric"] = lambda b: (
-        isinstance(b[0], int) or isinstance(b[0], float)
+        isinstance(b[0], int) or isinstance(b[0], (np.floating, float))
     )
     tests["lon_max must be numeric"] = lambda b: (
-        isinstance(b[1], int) or isinstance(b[1], float)
+        isinstance(b[1], int) or isinstance(b[1], (np.floating, float))
     )
     tests["lat_min must be numeric"] = lambda b: (
-        isinstance(b[2], int) or isinstance(b[2], float)
+        isinstance(b[2], int) or isinstance(b[2], (np.floating, float))
     )
     tests["lat_max must be numeric"] = lambda b: (
-        isinstance(b[3], int) or isinstance(b[3], float)
+        isinstance(b[3], int) or isinstance(b[3], (np.floating, float))
     )
     tests["pres_min must be numeric"] = lambda b: (
-        isinstance(b[4], int) or isinstance(b[4], float)
+        isinstance(b[4], int) or isinstance(b[4], (np.floating, float))
     )
     tests["pres_max must be numeric"] = lambda b: (
-        isinstance(b[5], int) or isinstance(b[5], float)
+        isinstance(b[5], int) or isinstance(b[5], (np.floating, float))
     )
     if len(box) == 8:
         tests[
@@ -1242,8 +1262,13 @@ def is_list_of_datasets(lst):
     return all(isinstance(x, xr.Dataset) for x in lst)
 
 
+def is_list_equal(lst1, lst2):
+    """ Return true if 2 lists contain same elements"""
+    return len(lst1) == len(lst2) and len(lst1) == sum([1 for i, j in zip(lst1, lst2) if i == j])
+
+
 def check_wmo(lst):
-    """ Check a WMO option and returned it as a list of integers
+    """ Validate a WMO option and returned it as a list of integers
 
     Parameters
     ----------
@@ -1269,7 +1294,7 @@ def check_wmo(lst):
 
 
 def is_wmo(lst, errors="raise"):  # noqa: C901
-    """ Assess validity of a WMO option value
+    """ Check if a WMO is valid
 
     Parameters
     ----------
@@ -1384,4 +1409,404 @@ def modified_environ(*remove, **update):
         yield
     finally:
         env.update(update_after)
-        [env.pop(k) for k in remove_after]
\ No newline at end of file
+        [env.pop(k) for k in remove_after]
+
+
+def toYearFraction(this_date: pd._libs.tslibs.timestamps.Timestamp = pd.to_datetime('now', utc=True)):
+    """ Compute decimal year, robust to leap years, precision to the second
+
+    Compute the fraction of the year a given timestamp corresponds to.
+    The "fraction of the year" goes:
+    - from 0 on 01-01T00:00:00.000 of the year
+    - to 1 on the 01-01T00:00:00.000 of the following year
+
+    1 second corresponds to the number of days in the year times 86400.
+    The faction of the year is rounded to 10-digits in order to have a "second" precision.
+
+    See discussion here: https://github.com/euroargodev/argodmqc_owc/issues/35
+
+    Parameters
+    ----------
+    pd._libs.tslibs.timestamps.Timestamp
+
+    Returns
+    -------
+    float
+    """
+    if "UTC" in [this_date.tzname() if not this_date.tzinfo is None else ""]:
+        startOfThisYear = pd.to_datetime("%i-01-01T00:00:00.000" % this_date.year, utc=True)
+    else:
+        startOfThisYear = pd.to_datetime("%i-01-01T00:00:00.000" % this_date.year)
+    yearDuration_sec = (startOfThisYear + pd.offsets.DateOffset(years=1) - startOfThisYear).total_seconds()
+
+    yearElapsed_sec = (this_date - startOfThisYear).total_seconds()
+    fraction = yearElapsed_sec / yearDuration_sec
+    fraction = np.round(fraction, 10)
+    return this_date.year + fraction
+
+
+def YearFraction_to_datetime(yf: float):
+    """ Compute datetime from year fraction
+
+    Inverse the toYearFraction() function
+
+    Parameters
+    ----------
+    float
+
+    Returns
+    -------
+    pd._libs.tslibs.timestamps.Timestamp
+    """
+    year = np.int32(yf)
+    fraction = yf - year
+    fraction = np.round(fraction, 10)
+
+    startOfThisYear = pd.to_datetime("%i-01-01T00:00:00" % year)
+    yearDuration_sec = (startOfThisYear + pd.offsets.DateOffset(years=1) - startOfThisYear).total_seconds()
+    yearElapsed_sec = pd.Timedelta(fraction * yearDuration_sec, unit='s')
+    return pd.to_datetime(startOfThisYear + yearElapsed_sec, unit='s')
+
+
+def wrap_longitude(grid_long):
+    """ Allows longitude (0-360) to wrap beyond the 360 mark, for mapping purposes.
+        Makes sure that, if the longitude is near the boundary (0 or 360) that we
+        wrap the values beyond
+        360 so it appears nicely on a map
+        This is a refactor between get_region_data and get_region_hist_locations to
+        avoid duplicate code
+
+        source: https://github.com/euroargodev/argodmqc_owc/blob/e174f4538fdae1534c9740491398972b1ffec3ca/pyowc/utilities.py#L80
+
+        Parameters
+        ----------
+        grid_long: array of longitude values
+
+        Returns
+        -------
+        array of longitude values that can extend past 360
+    """
+    neg_long = np.argwhere(grid_long < 0)
+    grid_long[neg_long] = grid_long[neg_long] + 360
+
+    # if we have data close to upper boundary (360), then wrap some of the data round
+    # so it appears on the map
+    top_long = np.argwhere(grid_long >= 320)
+    if top_long.__len__() != 0:
+        bottom_long = np.argwhere(grid_long <= 40)
+        grid_long[bottom_long] = 360 + grid_long[bottom_long]
+
+    return grid_long
+
+
+def wmo2box(wmo_id: int):
+    """ Convert WMO square box number into a latitude/longitude box
+
+    See:
+    https://en.wikipedia.org/wiki/World_Meteorological_Organization_squares
+    https://commons.wikimedia.org/wiki/File:WMO-squares-global.gif
+
+    Parameters
+    ----------
+    wmo_id: int
+        WMO square number, must be between 1000 and 7817
+
+    Returns
+    -------
+    box: list(int)
+        [lon_min, lon_max, lat_min, lat_max] bounds to the WMO square number
+    """
+    if wmo_id < 1000 or wmo_id > 7817:
+        raise ValueError("Invalid WMO square number, must be between 1000 and 7817.")
+    wmo_id = str(wmo_id)
+
+    # "global quadrant" numbers where 1=NE, 3=SE, 5=SW, 7=NW
+    quadrant = int(wmo_id[0])
+    if quadrant not in [1, 3, 5 ,7]:
+        raise ValueError("Invalid WMO square number, 1st digit must be 1, 3, 5 or 7.")
+
+    # 'minimum' Latitude square boundary, nearest to the Equator
+    nearest_to_the_Equator_latitude = int(wmo_id[1])
+
+    # 'minimum' Longitude square boundary, nearest to the Prime Meridian
+    nearest_to_the_Prime_Meridian = int(wmo_id[2:4])
+
+    #
+    dd = 10
+    if quadrant in [1, 3]:
+        lon_min = nearest_to_the_Prime_Meridian*dd
+        lon_max = nearest_to_the_Prime_Meridian*dd+dd
+    elif quadrant in [5, 7]:
+        lon_min = -nearest_to_the_Prime_Meridian*dd-dd
+        lon_max = -nearest_to_the_Prime_Meridian*dd
+
+    if quadrant in [1, 7]:
+        lat_min = nearest_to_the_Equator_latitude*dd
+        lat_max = nearest_to_the_Equator_latitude*dd+dd
+    elif quadrant in [3, 5]:
+        lat_min = -nearest_to_the_Equator_latitude*dd-dd
+        lat_max = -nearest_to_the_Equator_latitude*dd
+
+    box = [lon_min, lon_max, lat_min, lat_max]
+    return box
+
+
+def groupby_remap(z, data, z_regridded, z_dim=None, z_regridded_dim="regridded", output_dim="remapped", select='deep', right=False):
+    """ todo: Need a docstring here !"""
+
+    # sub-sampling called in xarray ufunc
+    def _subsample_bins(x, y, target_values):
+        # remove all nans from input x and y
+        idx = np.logical_or(np.isnan(x), np.isnan(y))
+        x = x[~idx]
+        y = y[~idx]
+
+        ifound = np.digitize(x, target_values, right=right)  # ``bins[i-1] <= x < bins[i]``
+        ifound -= 1  # Because digitize returns a 1-based indexing, we need to remove 1
+        y_binned = np.ones_like(target_values) * np.nan
+
+        for ib, this_ibin in enumerate(np.unique(ifound)):
+            ix = np.where(ifound == this_ibin)
+            iselect = ix[-1]
+
+            # Map to y value at specific x index in the bin:
+            if select == 'shallow':
+                iselect = iselect[0]  # min/shallow
+                mapped_value = y[iselect]
+            elif select == 'deep':
+                iselect = iselect[-1]  # max/deep
+                mapped_value = y[iselect]
+            elif select == 'middle':
+                iselect = iselect[np.where(x[iselect] >= np.median(x[iselect]))[0][0]]  # median/middle
+                mapped_value = y[iselect]
+            elif select == 'random':
+                iselect = iselect[np.random.randint(len(iselect))]
+                mapped_value = y[iselect]
+
+            # or Map to y statistics in the bin:
+            elif select == 'mean':
+                mapped_value = np.nanmean(y[iselect])
+            elif select == 'min':
+                mapped_value = np.nanmin(y[iselect])
+            elif select == 'max':
+                mapped_value = np.nanmax(y[iselect])
+            elif select == 'median':
+                mapped_value = np.median(y[iselect])
+
+            else:
+                raise InvalidOption("`select` option has invalid value (%s)" % select)
+
+            y_binned[this_ibin] = mapped_value
+
+        return y_binned
+
+    # infer dim from input
+    if z_dim is None:
+        if len(z.dims) != 1:
+            raise RuntimeError("if z_dim is not specified, x must be a 1D array.")
+        dim = z.dims[0]
+    else:
+        dim = z_dim
+
+    # if dataset is passed drop all data_vars that dont contain dim
+    if isinstance(data, xr.Dataset):
+        raise ValueError("Dataset input is not supported yet")
+        # TODO: for a dataset input just apply the function for each appropriate array
+
+    if version.parse(xr.__version__) > version.parse("0.15.0"):
+        kwargs = dict(
+            input_core_dims=[[dim], [dim], [z_regridded_dim]],
+            output_core_dims=[[output_dim]],
+            vectorize=True,
+            dask="parallelized",
+            output_dtypes=[data.dtype],
+            dask_gufunc_kwargs={'output_sizes': {output_dim: len(z_regridded[z_regridded_dim])}},
+        )
+    else:
+        kwargs = dict(
+            input_core_dims=[[dim], [dim], [z_regridded_dim]],
+            output_core_dims=[[output_dim]],
+            vectorize=True,
+            dask="parallelized",
+            output_dtypes=[data.dtype],
+            output_sizes={output_dim: len(z_regridded[z_regridded_dim])},
+        )
+    remapped = xr.apply_ufunc(_subsample_bins, z, data, z_regridded, **kwargs)
+
+    remapped.coords[output_dim] = z_regridded.rename({z_regridded_dim: output_dim}).coords[output_dim]
+    return remapped
+
+
+class TopoFetcher():
+    """ Fetch topographic data through an ERDDAP server for an ocean rectangle
+
+    Example:
+        >>> from argopy import TopoFetcher
+        >>> box = [-75, -45, 20, 30]  # Lon_min, lon_max, lat_min, lat_max
+        >>> ds = TopoFetcher(box).to_xarray()
+        >>> ds = TopoFetcher(box, ds='gebco', stride=[10, 10], cache=True).to_xarray()
+
+    """
+
+    class ERDDAP():
+        def __init__(self, server: str, protocol: str = 'tabledap'):
+            self.server = server
+            self.protocol = protocol
+            self.response = 'nc'
+            self.dataset_id = ''
+            self.constraints = ''
+
+    def __init__(
+            self,
+            box: list,
+            ds: str = "gebco",
+            cache: bool = False,
+            cachedir: str = "",
+            api_timeout: int = 0,
+            stride: list = [1, 1],
+            **kwargs,
+    ):
+        """ Instantiate an ERDDAP topo data fetcher
+
+        Parameters
+        ----------
+        ds: str (optional), default: 'gebco'
+            Dataset to load:
+
+            - 'gebco' will load the GEBCO_2020 Grid, a continuous terrain model for oceans and land at 15 arc-second intervals
+        stride: list, default [1, 1]
+            Strides along longitude and latitude. This allows to change the output resolution
+        cache: bool (optional)
+            Cache data or not (default: False)
+        cachedir: str (optional)
+            Path to cache folder
+        api_timeout: int (optional)
+            Erddap request time out in seconds. Set to OPTIONS['api_timeout'] by default.
+        """
+        timeout = OPTIONS["api_timeout"] if api_timeout == 0 else api_timeout
+        self.fs = httpstore(cache=cache, cachedir=cachedir, timeout=timeout, size_policy='head')
+        self.definition = "Erddap topographic data fetcher"
+
+        self.BOX = box
+        self.stride = stride
+        if ds == "gebco":
+            self.definition = "NOAA erddap gebco data fetcher for a space region"
+            self.server = 'https://coastwatch.pfeg.noaa.gov/erddap'
+            self.server_name = 'NOAA'
+            self.dataset_id = 'gebco'
+
+        self._init_erddap()
+
+    def _init_erddap(self):
+        # Init erddap
+        self.erddap = self.ERDDAP(server=self.server, protocol="griddap")
+        self.erddap.response = (
+            "nc"
+        )
+
+        if self.dataset_id == "gebco":
+            self.erddap.dataset_id = "GEBCO_2020"
+        else:
+            raise ValueError(
+                "Invalid database short name for %s erddap" % self.server_name
+            )
+        return self
+
+    def _cname(self) -> str:
+        """ Fetcher one line string definition helper """
+        cname = "?"
+
+        if hasattr(self, "BOX"):
+            BOX = self.BOX
+            cname = ("[x=%0.2f/%0.2f; y=%0.2f/%0.2f]") % (
+                BOX[0],
+                BOX[1],
+                BOX[2],
+                BOX[3],
+            )
+        return cname
+
+    def __repr__(self):
+        summary = ["<topofetcher.erddap>"]
+        summary.append("Name: %s" % self.definition)
+        summary.append("API: %s" % self.server)
+        summary.append("Domain: %s" % format_oneline(self.cname()))
+        return "\n".join(summary)
+
+    def cname(self):
+        """ Return a unique string defining the constraints """
+        return self._cname()
+
+    @property
+    def cachepath(self):
+        """ Return path to cached file(s) for this request
+
+        Returns
+        -------
+        list(str)
+        """
+        return [self.fs.cachepath(uri) for uri in self.uri]
+
+    def define_constraints(self):
+        """ Define request constraints """
+        #        Eg: https://coastwatch.pfeg.noaa.gov/erddap/griddap/GEBCO_2020.nc?elevation%5B(34):5:(42)%5D%5B(-21):7:(-12)%5D
+        self.erddap.constraints = "%s(%0.2f):%i:(%0.2f)%s%s(%0.2f):%i:(%0.2f)%s" % (
+        "%5B", self.BOX[2], self.stride[1], self.BOX[3], "%5D",
+        "%5B", self.BOX[0], self.stride[0], self.BOX[1], "%5D")
+        return None
+
+    #     @property
+    #     def _minimal_vlist(self):
+    #         """ Return the minimal list of variables to retrieve """
+    #         vlist = list()
+    #         vlist.append("latitude")
+    #         vlist.append("longitude")
+    #         vlist.append("elevation")
+    #         return vlist
+
+    def get_url(self):
+        """ Return the URL to download data requested
+
+        Returns
+        -------
+        str
+        """
+        # First part of the URL:
+        protocol = self.erddap.protocol
+        dataset_id = self.erddap.dataset_id
+        response = self.erddap.response
+        url = f"{self.erddap.server}/{protocol}/{dataset_id}.{response}?"
+
+        # Add variables to retrieve:
+        variables = ["elevation"]
+        variables = ",".join(variables)
+        url += f"{variables}"
+
+        # Add constraints:
+        self.define_constraints()  # Define constraint to select this box of data (affect self.erddap.constraints)
+        url += f"{self.erddap.constraints}"
+
+        return url
+
+    @property
+    def uri(self):
+        """ List of files to load for a request
+
+        Returns
+        -------
+        list(str)
+        """
+        return [self.get_url()]
+
+    def to_xarray(self, errors: str = 'ignore'):
+        """ Load Topographic data and return a xarray.DataSet """
+
+        # Download data
+        if len(self.uri) == 1:
+            ds = self.fs.open_dataset(self.uri[0])
+
+        return ds
+
+    def load(self, errors: str = 'ignore'):
+        """ Load Topographic data and return a xarray.DataSet """
+        return self.to_xarray(errors=errors)
